import { URI } from '@vscode-alt/monaco-editor/esm/vs/base/common/uri';
import { Extensions } from '@adminide-stack/core';
import { createProxyAndHandleRequests } from '@adminide-stack/extension-api';
import { Subscription, fromEventPattern } from 'rxjs';

/* tslint:disable */
class ClientConfigurationPolicy {
    _organizationContextService;
    configurationService;
    _registry;
    subscriptions = new Subscription();
    proxy;
    constructor(connection, _organizationContextService, configurationService, 
    // private readonly _environmentService: IEnvironmentService,
    // @sri added
    _registry) {
        this._organizationContextService = _organizationContextService;
        this.configurationService = configurationService;
        this._registry = _registry;
        this.proxy = createProxyAndHandleRequests('configurationPolicy', connection, this);
        this.proxy.$initializeConfiguration(this._getConfigurationData());
        this.subscriptions.add(fromEventPattern(configurationService.onDidChangeConfiguration)
            .subscribe(event => {
            this.proxy.$acceptConfigurationChanged(this._getConfigurationData(), event.change);
        }));
    }
    _getConfigurationData() {
        const configurationData = { ...this.configurationService.getConfigurationData(), configurationScopes: {} };
        // Send configurations scopes only in development mode.
        // if (!this._environmentService.isBuilt || this._environmentService.isExtensionDevelopment) {
        // @sri custom way
        // const configurationRegistry = this._registry.as<IConfigurationRegistry>(Extensions.Configuration);
        // configurationData.configurationScopes = getScopes(configurationRegistry);
        // }
        return configurationData;
    }
    $updateConfigurationOption(target, key, value, overrides) {
        overrides = { resource: overrides?.resource ? URI.revive(overrides.resource) : undefined, overrideIdentifier: overrides?.overrideIdentifier };
        return this.writeConfiguration(target, key, value, overrides);
    }
    $removeConfigurationOption(target, key, overrides) {
        overrides = { resource: overrides?.resource ? URI.revive(overrides.resource) : undefined, overrideIdentifier: overrides?.overrideIdentifier };
        return this.writeConfiguration(target, key, undefined, overrides);
    }
    unsubscribe() {
        this.subscriptions.unsubscribe();
    }
    writeConfiguration(target, key, value, overrides) {
        target = target !== null && target !== undefined ? target : this.deriveConfigurationTarget(key, overrides);
        return this.configurationService.updateValue(key, value, overrides, target, true);
    }
    deriveConfigurationTarget(key, overrides) {
        if (overrides.resource && this._organizationContextService.getApplicationState() === 3 /* ApplicationState.ORGANIZATION */) {
            const configurationProperties = this._registry.as(Extensions.Configuration).getConfigurationProperties();
            if (configurationProperties[key] && configurationProperties[key].scope === 4 /* ConfigurationScope.RESOURCE */) {
                return 5 /* ConfigurationTarget.ORGANIZATION_RESOURCE */;
            }
        }
        return 4 /* ConfigurationTarget.ORGANIZATION */;
    }
}

export { ClientConfigurationPolicy };
//# sourceMappingURL=client-configuration-policy.js.map
