import * as React from 'react';
import { css } from '@emotion/css';
import { Avatar, Tag, Rate, Button } from 'antd';
import { AiOutlineCloudDownload } from '@react-icons/all-files/ai/AiOutlineCloudDownload.js';

const ExtensionHeader = (props) => {
    const { extension = {}, onInstall } = props;
    return (React.createElement("div", { className: css(styles.header) },
        React.createElement("div", { className: css(styles.icon) },
            React.createElement(Avatar, { size: 72, src: extension.icon }, extension.displayName)),
        React.createElement("div", { className: css(styles.content) },
            React.createElement("div", { className: css(styles.name) },
                React.createElement("h3", null, extension.name || 'untitles'),
                React.createElement(Tag, null, extension.extensionID)),
            React.createElement("div", { className: css(styles.info) },
                React.createElement("div", null, extension.publisherDisplayName || 'author'),
                React.createElement("div", null,
                    React.createElement(AiOutlineCloudDownload, { style: { fontSize: 'large' } }),
                    ' ',
                    extension.installCount || 0),
                React.createElement("div", null,
                    React.createElement(Rate, { style: { fontSize: '12px' }, disabled: true, value: 0 })),
                React.createElement("div", null,
                    React.createElement("a", { href: "#" }, "Repository"))),
            React.createElement("div", { className: css(styles.description) }, extension.description),
            React.createElement("div", { className: css(styles.actions) },
                React.createElement(Button, { onClick: () => onInstall(extension.id), type: "primary", size: "small" }, 'Install')))));
};
const styles = {
    header: {
        width: '100%',
        display: 'flex',
        padding: '15px',
        cursor: 'pointer',
        flexDirection: 'row',
    },
    icon: {
        flexGrow: 0,
        margin: '0 15px 0 0',
    },
    content: {
        flexGrow: 1,
        margin: '0 0 0 15px',
    },
    name: {
        display: 'flex',
        margin: '0 0 5px 0',
        flexDirection: 'row',
        '& > h3': {
            marginRight: '10px',
        },
    },
    info: {
        display: 'flex',
        margin: '0 0 5px 0',
        flexDirection: 'row',
        '& > div': {
            margin: '0 5px',
            '&:first-child': {
                marginLeft: 0,
            },
            '&:lsat-child': {
                marginRight: 0,
            },
        },
    },
    description: {
        margin: '0 0 5px 0',
    },
};

export { ExtensionHeader };
//# sourceMappingURL=ExtensionHeader.js.map
