import { get, map } from 'lodash-es';
import * as React from 'react';
import { css } from '@emotion/css';
import { useInstalledExtensionsQuery, useRemoveMutation } from '../components/generated.js';
import { ExtensionsList } from '../components/ExtensionsList.js';

const Installed = (props) => {
    const { data: installed, loading, ...installedResult } = useInstalledExtensionsQuery();
    const [removeExtension] = useRemoveMutation();
    const onRemove = (mutate) => (id) => {
        mutate({ variables: { id } }).then(() => installedResult.refetch());
    };
    const list = React.useMemo(() => get(installed, 'installed'), [installed]);
    const extensions = React.useMemo(() => map(list, 'extension'), [list]);
    return (React.createElement("div", { className: css(styles.root) },
        React.createElement(ExtensionsList, { mode: "installed", loading: loading, extensions: extensions, onRemove: onRemove(removeExtension), onSelect: (id) => {
                console.log('Selected Extension ID ', id);
            } })));
};
const styles = {
    root: {
        width: '100%',
        height: '100%',
        display: 'flex',
        overflowY: 'auto',
        flexDirection: 'column',
    },
};

export { Installed };
//# sourceMappingURL=Installed.js.map
