import { Feature } from '@common-stack/client-react';
import { ClientTypes } from '@adminide-stack/extension-api';
import { extensionModule } from './inversify-containers/module.js';
import { registerCommandEpic, deregisterCommandEpic, executeCommandEpic } from './services/command-epic.js';
import { getActiveContributionsEpic, registerContributionsEpic, deregisterContributionsEpic } from './services/contribution-epics.js';
import { onLocationChangedToLoadExtEpic } from './epics/load-extension-script.js';
import { loadExtensionController } from './util/loadExtensionController.js';

const extensionServiceGen = (container) => ({
    model: container.get(ClientTypes.IModelService),
    viewer: container.get(ClientTypes.IViewerService),
    contribution: container.get(ClientTypes.IContributionRegistry),
    commands: container.get(ClientTypes.ICommandRegistry),
});
var extensions = new Feature({
    epic: [
        onLocationChangedToLoadExtEpic,
        getActiveContributionsEpic,
        registerCommandEpic,
        registerContributionsEpic,
        deregisterContributionsEpic,
        deregisterCommandEpic,
        executeCommandEpic,
    ],
    async beforeSSR({ request }) {
        const { apolloClient, services, container } = request;
        loadExtensionController(container);
    },
    // clientStateParams: [{ resolvers, typeDefs: editorSchema }],
    // routeConfig: filteredRoutes,
    createContainerFunc: extensionModule,
    createServiceFunc: extensionServiceGen,
});

export { extensions as default };
//# sourceMappingURL=module.js.map
